@@ -11,8 +11,6 @@ use {
     solana_sdk::{
         account::{AccountSharedData, ReadableAccount, WritableAccount},
         genesis_config::GenesisConfig,
-        instruction::InstructionError,
-        keyed_account::KeyedAccount,
         stake::config::{self, Config},
     },
 };
@@ -23,13 +21,6 @@ pub fn from<T: ReadableAccount>(account: &T) -> Option<Config> {
         .and_then(|data| deserialize(data).ok())
 }
 
-pub fn from_keyed_account(account: &KeyedAccount) -> Result<Config, InstructionError> {
-    if !config::check_id(account.unsigned_key()) {
-        return Err(InstructionError::InvalidArgument);
-    }
-    from(&*account.try_account_ref()?).ok_or(InstructionError::InvalidArgument)
-}
-
 pub fn create_account(lamports: u64, config: &Config) -> AccountSharedData {
     create_config_account(vec![], config, lamports)
 }
@@ -47,15 +38,11 @@ pub fn add_genesis_account(genesis_config: &mut GenesisConfig) -> u64 {
 
 #[cfg(test)]
 mod tests {
-    use {super::*, solana_sdk::pubkey::Pubkey, std::cell::RefCell};
+    use {super::*, std::cell::RefCell};
 
     #[test]
     fn test() {
         let account = RefCell::new(create_account(0, &Config::default()));
         assert_eq!(from(&account.borrow()), Some(Config::default()));
-        assert_eq!(
-            from_keyed_account(&KeyedAccount::new(&Pubkey::default(), false, &account)),
-            Err(InstructionError::InvalidArgument)
-        );
     }
 }
